@@ -1,5 +1,5 @@
 #' Check the format of time series
-#' 
+#'
 #' @param y time series y in matrix format (\code{n} rows x 2 columns). The
 #'   first column should contain the time steps and the second column should
 #'   contain the values.
@@ -9,22 +9,22 @@
 #' @param x2 time series x2 in matrix format (\code{n} rows x 2 columns). The
 #'   first column should contain the time steps and the second column should
 #'   contain the values.
-#'   
+#'
 #' @return Returns a named list containing:
 #' \item{t}{time steps}
 #' \item{dt}{size of a time step}
 #' \item{n.obs}{number of observations}
-#' 
+#'
 #' @references
-#' Torrence, C., and G. P. Compo. 1998. A Practical Guide to Wavelet Analysis. 
+#' Torrence, C., and G. P. Compo. 1998. A Practical Guide to Wavelet Analysis.
 #' \emph{Bulletin of the American Meteorological Society} 79:61-78.
-#' 
+#'
 #' @author Tarik C. Gouhier (tarik.gouhier@@gmail.com)
-#' 
+#'
 #' @examples
 #' t1 <- cbind(1:100, rnorm(100))
 #' check.data(y = t1)
-#' 
+#'
 #' @export
 check.data <- function(y, x1 = NULL, x2 = NULL) {
 
@@ -58,29 +58,25 @@ check.data <- function(y, x1 = NULL, x2 = NULL) {
 #' @note This function is not exported
 check.datum <- function(x) {
   if (NCOL(x) > 1) {
-    if (class(x[, 1])[1] == "Date" | class(x[,1])[1] == "POSIXct") {
-      diffs <- diff(x[, 1])
-      if (all(diffs == diffs[1])) {
-        t <- x[, 1]
-        dt <- as.numeric(diffs[1])
-      } else {
-        t <- seq_len(NROW(x))
-        dt <- diff(t)[1]
-      }
-    } else {
-      dt <- diff(x[, 1])[1]
-      t <- x[, 1]
-    }
-
+    diffs <- diff(x[, 1])
+    t <- x[, 1]
+    dt <- as.numeric(diffs[1])
     epsilon <- 0.1 * dt
 
-    if (any(abs(diff(t) - dt) > epsilon * dt)) {
+    if (any(abs(diff(t) - dt) > (epsilon * dt))) {
       stop("The step size must be constant ",
            "(see approx function to interpolate)")
     }
+
+    if (class(x[, 1])[1] == "Date" | class(x[,1])[1] == "POSIXct") {
+      tindex <- seq_len(NROW(x))
+    } else {
+      tindex <- x[, 1]
+    }
+
   } else {
     stop("Error: the data must be in the form of an n x 2 matrix ",
          "containing the time steps in column 1 and the values in column 2")
   }
-  return(list(t = t, dt = dt, n.obs = NROW(x)))
+  return(list(t = tindex, dt = dt, n.obs = NROW(x)))
 }
